@@ -40,6 +40,13 @@ class ExcelDashboarder:
     const_str__config_label__str_wb_set_properties: str = "workbook.set_properties"
 
     const_str__config_label__str_ws_set_column: str = "worksheet.set_column"
+    const_str__config_label__ws_set_column__cell_format__as_dict: str = "cell_format"
+    const_str__config_label__ws_set_column__first_col__as_int: str = "first_col"
+    const_str__config_label__ws_set_column__last_col__as_int: str = "last_col"
+    const_str__config_label__ws_set_column__options__as_dict: str = "options"
+    const_str__config_label__ws_set_column__options__hidden__as_int: str = "hidden"
+    const_str__config_label__ws_set_column__options__level__as_int: str = "level"
+    const_str__config_label__ws_set_column__width__as_float: str = "width"
 
     _logger: Logger = getLogger(__name__)
 
@@ -422,18 +429,20 @@ class ExcelDashboarder:
             for i_set_column in dict_worksheet_config[self.const_str__config_label__str_ws_set_column]:
 
                 # We instantiate the cell format, if any was provided
-                dict_the_format: dict = i_set_column.get("cell_format", None)
+                dict_the_format: dict = i_set_column.get(
+                    self.const_str__config_label__ws_set_column__cell_format__as_dict, None
+                )
                 obj_the_format: Optional[Format] = None
                 if dict_the_format is not None:
                     obj_the_format = wb_workbook.add_format(dict_the_format)
 
                 # We set the column(s)...
                 ws_the_worksheet.set_column(
-                    first_col=i_set_column["first_col"],
-                    last_col=i_set_column["last_col"],
-                    width=i_set_column.get("width", None),
+                    first_col=i_set_column[self.const_str__config_label__ws_set_column__first_col__as_int],
+                    last_col=i_set_column[self.const_str__config_label__ws_set_column__last_col__as_int],
+                    width=i_set_column.get(self.const_str__config_label__ws_set_column__width__as_float, None),
                     cell_format=obj_the_format,
-                    options=i_set_column.get("options", None),
+                    options=i_set_column.get(self.const_str__config_label__ws_set_column__options__as_dict, None),
                 )
 
         # We check if the sheet is to be hidden
